"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ViewCompilationGate = void 0;
class ViewCompilationGate {
    shouldCompile;
    constructor() {
        this.shouldCompile = false;
    }
    compile(cubes) {
        // When developing Data Access Policies feature, we've came across a
        // limitation that Cube members can't be referenced in access policies defined on Views,
        // because views aren't (yet) compiled at the time of access policy evaluation.
        // To workaround this limitation and additional compilation pass is necessary,
        // however it comes with a significant performance penalty.
        // This gate check whether the data model contains views with access policies,
        // and only then allows the additional compilation pass.
        //
        // Check out the DataSchemaCompiler.ts to see how this gate is used.
        if (this.viewsHaveAccessPolicies(cubes)) {
            this.shouldCompile = true;
        }
    }
    viewsHaveAccessPolicies(cubes) {
        return cubes.some(c => c.isView && c.accessPolicy);
    }
    shouldCompileViews() {
        return this.shouldCompile;
    }
}
exports.ViewCompilationGate = ViewCompilationGate;
//# sourceMappingURL=ViewCompilationGate.js.map